@@ -30,6 +30,10 @@ GROUP_ATTR_DEFAULTS = {
     'cmd_wrapper_outer': "sudo -u {1} sh -c {0}",
     'lock_dir': "/var/lib/bundlewrap",
     'dummy': False,
+    'ipmi_hostname': None,
+    'ipmi_interface': None,
+    'ipmi_username': None,
+    'ipmi_password': None,
     'kubectl_context': None,
     'locking_node': None,
     'os': 'linux',
@@ -61,10 +65,14 @@ GROUP_ATTR_TYPES = {
     'bundles': COLLECTION_OF_STRINGS,
     'cmd_wrapper_inner': str,
     'cmd_wrapper_outer': str,
-    'lock_dir': str,
     'dummy': bool,
     'file_path': str,
+    'ipmi_hostname': (str, type(None)),
+    'ipmi_interface': (str, type(None)),
+    'ipmi_username': (str, Fault, type(None)),
+    'ipmi_password': (str, Fault, type(None)),
     'kubectl_context': (str, type(None)),
+    'lock_dir': str,
     'locking_node': (str, type(None)),
     'member_patterns': COLLECTION_OF_STRINGS,
     'members': COLLECTION_OF_STRINGS,
@@ -73,8 +81,8 @@ GROUP_ATTR_TYPES = {
     'os_version': LIST_OR_TUPLE_OF_INTS,
     'password': (Fault, str, type(None)),
     'pip_command': str,
-    'subgroups': COLLECTION_OF_STRINGS,
     'subgroup_patterns': COLLECTION_OF_STRINGS,
+    'subgroups': COLLECTION_OF_STRINGS,
     'supergroups': COLLECTION_OF_STRINGS,
     'use_shadow_passwords': bool,
     'username': (Fault, str, type(None)),
