@@ -7,7 +7,7 @@ from bundlewrap.exceptions import BundleError
 from bundlewrap.metadata import metadata_to_json
 from bundlewrap.items import BUILTIN_ITEM_ATTRIBUTES, Item
 from bundlewrap.items.files import content_processor_jinja2, content_processor_mako
-from bundlewrap.utils.dicts import diff_value_text, merge_dict, reduce_dict
+from bundlewrap.utils.dicts import merge_dict, reduce_dict
 from bundlewrap.utils.ui import io
 from bundlewrap.utils.text import force_text, mark_for_translation as _
 import yaml
@@ -57,14 +57,6 @@ class KubernetesItem(Item, metaclass=ABCMeta):
                 indent=4, sort_keys=True,
             )}
 
-    def display_on_create(self, cdict):
-        cdict['manifest'] = diff_value_text("", "", force_text(cdict['manifest'])).rstrip("\n")
-        return cdict
-
-    def display_on_delete(self, sdict):
-        sdict['manifest'] = diff_value_text("", force_text(sdict['manifest']), "").rstrip("\n")
-        return sdict
-
     def fix(self, status):
         if status.must_be_deleted:
             result = self.run_local(self._kubectl + ["delete", self.KIND, self.resource_name])
@@ -175,7 +167,21 @@ class KubernetesItem(Item, metaclass=ABCMeta):
         return self._manifest_dict['metadata']['name']
 
     def sdict(self):
-        result = self.run_local(self._kubectl + ["get", "-o", "json", self.KIND, self.resource_name])
+        # Include apiVersion in object name to stop k8s from chosing an
+        # apiVersion randomly.
+        version_spec = [self.KIND]
+        if '/' in self._manifest_dict['apiVersion']:
+            group, version = self._manifest_dict['apiVersion'].split('/')
+            version_spec.append(version)
+            version_spec.append(group)
+        else:
+            version_spec.append(self._manifest_dict['apiVersion'])
+            # Yes, it has to be something like:
+            # kubectl ... get -o json Secret.v1./token
+            version_spec.append('')
+        request_name = '{}/{}'.format('.'.join(version_spec), self.resource_name)
+
+        result = self.run_local(self._kubectl + ["get", "-o", "json", request_name])
         if result.return_code == 0:
             full_json_response = json.loads(result.stdout.decode('utf-8'))
             if full_json_response.get("status", {}).get("phase") == "Terminating":
