@@ -13,15 +13,18 @@ from .exceptions import (
     TransportException,
 )
 from .utils import cached_property, tempfile
+from .utils.table import ROW_SEPARATOR, render_table
 from .utils.text import (
     blue,
     bold,
     format_duration,
     format_timestamp,
+    green,
     mark_for_translation as _,
     parse_duration,
     red,
     wrap_question,
+    yellow,
 )
 from .utils.ui import io
 
@@ -212,6 +215,35 @@ def softlock_add(node, lock_id, comment="", expiry="8h", item_selectors=None):
     return lock_id
 
 
+def softlock_add_and_warn_for_others(node, *args, **kwargs):
+    new_lock_id = softlock_add(node, *args, **kwargs)
+
+    other_peoples_soft_locks = {node.name: []}
+    for lock in softlock_list(node):
+        if lock['user'] != identity():
+            other_peoples_soft_locks[node.name].append(lock)
+
+    if other_peoples_soft_locks[node.name]:
+        output, _ignore = softlocks_to_table(other_peoples_soft_locks)
+
+        io.stdout(_("{x}").format(x=yellow("!")))
+        io.stdout(_(
+            "{x} {node}  Your lock was added, but the node was already locked by other people:"
+        ).format(
+            x=yellow("!"),
+            node=bold(node.name),
+        ))
+        io.stdout(_("{x}").format(x=yellow("!")))
+
+        # TODO 5.0 Just use "page_lines(output)" here
+        # For backwards compatibility, we don't use a pager, because
+        # this might break people's workflows/scripts.
+        for line in output:
+            io.stdout(line)
+
+    return new_lock_id
+
+
 def softlock_list(node):
     locking_node = _get_locking_node(node)
     if locking_node.os not in locking_node.OS_FAMILY_UNIX:
@@ -252,3 +284,89 @@ def softlock_remove(node, lock_id):
     ))
     locking_node.run("rm {}".format(_soft_lock_file(node.name, locking_node, lock_id)))
     node.repo.hooks.lock_remove(node.repo, node, lock_id)
+
+
+def softlocks_to_table(locks_on_node, items=None, repo=None):
+    rows = [[
+        bold(_("node")),
+        bold(_("ID")),
+        bold(_("created")),
+        bold(_("expires")),
+        bold(_("user")),
+        bold(_("items")),
+        bold(_("comment")),
+    ], ROW_SEPARATOR]
+
+    for node_name, locks in sorted(locks_on_node.items()):
+        if locks:
+            first_lock = True
+            for lock in locks:
+                lock['formatted_date'] = format_timestamp(lock['date'])
+                lock['formatted_expiry'] = format_timestamp(lock['expiry'])
+                first_item = True
+                for item in lock['items']:
+                    rows.append([
+                        node_name if first_item and first_lock else "",
+                        lock['id'] if first_item else "",
+                        lock['formatted_date'] if first_item else "",
+                        lock['formatted_expiry'] if first_item else "",
+                        lock['user'] if first_item else "",
+                        item,
+                        lock['comment'] if first_item else "",
+                    ])
+                    # always repeat for grep style
+                    first_item = environ.get("BW_TABLE_STYLE") == 'grep'
+                # always repeat for grep style
+                first_lock = environ.get("BW_TABLE_STYLE") == 'grep'
+        else:
+            rows.append([
+                node_name,
+                _("(none)"),
+                "",
+                "",
+                "",
+                "",
+                "",
+            ])
+
+        rows.append(ROW_SEPARATOR)
+
+    output = list(render_table(
+        rows[:-1],  # remove trailing ROW_SEPARATOR
+        alignments={1: 'center'},
+    ))
+
+    some_selected_items_locked = False
+
+    if items:
+        rows = [[
+            bold(_("node")),
+            bold(_("item")),
+            bold(_("locked")),
+            bold(_("ID")),
+        ], ROW_SEPARATOR]
+        for node_name, locks in sorted(locks_on_node.items()):
+            node = repo.get_node(node_name)
+            for item in sorted(node.items):
+                if not item.covered_by_autoskip_selector(items):
+                    continue
+                locked_by = None
+                for lock in locks:
+                    if item.covered_by_autoskip_selector(lock['items']):
+                        locked_by = lock['id']
+                        some_selected_items_locked = True
+                        break
+                rows.append([
+                    node.name,
+                    item.id,
+                    red(_("YES")) if locked_by else green(_("NO")),
+                    locked_by or "",
+                ])
+            if rows[-1] != ROW_SEPARATOR:
+                rows.append(ROW_SEPARATOR)
+
+        output += list(render_table(
+            rows[:-1],  # remove trailing ROW_SEPARATOR
+        ))
+
+    return output, some_selected_items_locked
