@@ -4,7 +4,7 @@ from inspect import isabstract
 from os import listdir, mkdir, walk
 from os.path import abspath, dirname, isdir, isfile, join
 
-from pkg_resources import DistributionNotFound, require, VersionConflict
+from pkg_resources import DistributionNotFound, require, VersionConflict  # needs setuptools
 try:
     from tomllib import loads as toml_load
 except ImportError:
@@ -31,7 +31,7 @@ from .utils import (
 )
 from .utils.scm import get_git_branch, get_git_clean, get_rev
 from .utils.dicts import hash_statedict
-from .utils.text import mark_for_translation as _, red, validate_name
+from .utils.text import bold, mark_for_translation as _, red, validate_name
 from .utils.ui import io
 
 DIRNAME_BUNDLES = "bundles"
@@ -53,6 +53,7 @@ HOOK_EVENTS = (
     'lock_add',
     'lock_remove',
     'lock_show',
+    'node_ssh_connect',
     'node_apply_end',
     'node_apply_start',
     'node_run_end',
@@ -124,7 +125,11 @@ class HooksProxy:
             # define a function that calls all hook functions
             def hook(*args, **kwargs):
                 for filename in files:
-                    self.__module_cache[filename][event](*args, **kwargs)
+                    with io.job(_("{event}  Running hooks from {filename}").format(
+                        event=bold(event),
+                        filename=filename,
+                    )):
+                        self.__module_cache[filename][event](*args, **kwargs)
             self.__hook_cache[event] = hook
 
         return self.__hook_cache[event]
@@ -199,10 +204,11 @@ class Repository(MetadataGenerator):
         self._get_all_attr_code_cache = {}
         self._get_all_attr_result_cache = {}
 
-        if repo_path is not None:
-            self.populate_from_path(self.path)
-        else:
-            self.item_classes = list(self.items_from_dir(items.__path__[0]))
+        with io.job("Loading repository"):
+            if repo_path is not None:
+                self.populate_from_path(self.path)
+            else:
+                self.item_classes = list(self.items_from_dir(items.__path__[0]))
 
     def __eq__(self, other):
         if self.path == "/dev/null":
