@@ -218,6 +218,9 @@ class IOManager:
         self._waiting_for_input = False
 
     def activate(self):
+        if self._active:
+            return
+
         self._active = True
         if 'BW_DEBUG_LOG_DIR' in environ:
             self.debug_log_file = open(join(
@@ -236,8 +239,8 @@ class IOManager:
         # the thread once the soft shutdown has completed
         self._signal_handler_thread.daemon = True
         self._signal_handler_thread.start()
-        signal(SIGINT, sigint_handler)
-        signal(SIGQUIT, sigquit_handler)
+        self._original_sigint_handler = signal(SIGINT, sigint_handler)
+        self._original_sigquit_handler = signal(SIGQUIT, sigquit_handler)
         faulthandler.enable()
         if TTY:
             write_to_stream(STDOUT_WRITER, HIDE_CURSOR)
@@ -282,11 +285,14 @@ class IOManager:
         return answer
 
     def deactivate(self):
+        if not self._active:
+            return
+
         self._active = False
         if TTY:
             write_to_stream(STDOUT_WRITER, SHOW_CURSOR)
-        signal(SIGINT, SIG_DFL)
-        signal(SIGQUIT, SIG_DFL)
+        signal(SIGINT, self._original_sigint_handler)
+        signal(SIGQUIT, self._original_sigint_handler)
         faulthandler.disable()
         self._signal_handler_thread.join()
         if self.debug_log_file:
