@@ -191,3 +191,67 @@ def test_tag_inheritance_loop(tmpdir):
     assert "inherited" in stdout.decode()
     assert "looped" in stdout.decode()
     assert "action:dep" in stdout.decode()
+
+
+def test_duplicate_items(tmpdir):
+    make_repo(
+        tmpdir,
+        nodes={
+            "node1": {
+                'bundles': ["bundle1", "bundle2"],
+            },
+        },
+        bundles={
+            "bundle1": {
+                'items': {
+                    'actions': {
+                        "dupl": {
+                            'command': "true",
+                        },
+                    },
+                },
+            },
+            "bundle2": {
+                'items': {
+                    'actions': {
+                        "dupl": {
+                            'command': "true",
+                        },
+                    },
+                },
+            },
+        },
+    )
+    stdout, stderr, rcode = run("bw items node1", path=str(tmpdir))
+    assert rcode == 1
+    assert "action:dupl" in stderr.decode()
+    assert "bundle1" in stderr.decode()
+    assert "bundle2" in stderr.decode()
+
+
+def test_show_auto_needs(tmpdir):
+    make_repo(
+        tmpdir,
+        nodes={
+            "node1": {
+                'bundles': ["bundle1"],
+            },
+        },
+        bundles={
+            "bundle1": {
+                'items': {
+                    'directories': {
+                        "/foo": {},
+                        "/foo/bar": {'needs': {"action:"}},
+                    },
+                },
+            },
+        },
+    )
+    stdout, stderr, rcode = run("BW_TABLE_STYLE=grep bw items --attr node1 directory:/foo/bar needs", path=str(tmpdir))
+    assert stdout.decode() == """attribute\tvalue
+needs\taction:
+needs\tdirectory:/foo
+"""
+    assert stderr.decode() == ""
+    assert rcode == 0
